CandidatePair

Struct CandidatePair 

pub struct CandidatePair {
    pub local_index: usize,
    pub remote_index: usize,
    pub local_priority: u32,
    pub remote_priority: u32,
    /* private fields */
}
Represents a combination of a local and remote candidate.

Fields

local_index: usize

Index of the local candidate in the agent’s list.

remote_index: usize

Index of the remote candidate in the agent’s list.

local_priority: u32

The local candidate’s priority.

remote_priority: u32

The remote candidate’s priority.

Implementations

Source

impl CandidatePair

pub fn new( local_index: usize, remote_index: usize, local_priority: u32, remote_priority: u32, ice_role_controlling: bool, ) -> Self

Forms a pair from a local and a remote candidate.

controlling selects which priority dominates in the pair’s combined priority.

pub fn priority(&self) -> u64

RFC 5245 - 5.7.2. Computing Pair Priority and Ordering Pairs Let G be the priority for the candidate provided by the controlling agent. Let D be the priority for the candidate provided by the controlled agent. pair priority = 2^32MIN(G,D) + 2MAX(G,D) + (G>D?1:0)

pub fn on_request_sent(&mut self)

Called when a STUN binding request is sent.

pub fn on_request_received(&mut self)

Called when a STUN binding request is received.

pub fn on_response_sent(&mut self)

Called when a STUN binding success response is sent.

pub fn on_response_received(&mut self, rtt: Duration)

Called when a STUN binding success response is received. Also updates RTT measurements.

Called when a consent freshness request is sent (keepalive).