ConnectionState

Enum ConnectionState 

pub enum ConnectionState {
    Unspecified,
    New,
    Checking,
    Connected,
    Completed,
    Failed,
    Disconnected,
    Closed,
}
An enum showing the state of a ICE Connection List of supported States.

Variants



Unspecified



New

ICE agent is gathering addresses.



Checking

ICE agent has been given local and remote candidates, and is attempting to find a match.



Connected

ICE agent has a pairing, but is still checking other pairs.



Completed

ICE agent has finished.



Failed

ICE agent never could successfully connect.



Disconnected

ICE agent connected successfully, but has entered a failed state.



Closed

ICE agent has finished and is no longer handling requests.