pub enum Event {
ConnectionStateChange(ConnectionState),
SelectedCandidatePairChange(Box<Candidate>, Box<Candidate>),
RoleChange(bool),
}Variants
ConnectionStateChange(ConnectionState)
SelectedCandidatePairChange(Box<Candidate>, Box<Candidate>)
RoleChange(bool)
Emitted when the ICE role switches due to a role conflict (RFC 8445 7.3.1.1).
The bool is true if the agent is now controlling, false if now controlled.