pub struct CandidateStats {
pub timestamp: Instant,
pub id: String,
pub ip: String,
pub port: u16,
pub candidate_type: CandidateType,
pub priority: u32,
pub url: String,
pub relay_protocol: String,
pub deleted: bool,
}Expand description
CandidateStats contains ICE candidate statistics related to the ICETransport objects.
Fields
timestamp: InstantThe timestamp associated with this object.
id: StringThe candidate id.
ip: StringThe ip address of the candidate, allowing for IPv4 addresses and. IPv6 addresses, but fully qualified domain names (FQDNs) are not allowed.
port: u16The port number of the candidate.
candidate_type: CandidateTypeThe “Type” field of the ICECandidate.
priority: u32The “priority” field of the ICECandidate.
url: StringThe url of the TURN or STUN server indicated in the that translated this ip address. It is the url address surfaced in an PeerConnectionICEEvent.
relay_protocol: StringThe protocol used by the endpoint to communicate with the. TURN server. This is only present for local candidates. Valid values for the TURN url protocol is one of udp, tcp, or tls.
deleted: boolOnly defined for local candidates. For remote candidates, this property is not applicable.